# Changelog

All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),

## [Unreleased]

## [0.2.0]

### Changed

- using python 3.12

## [0.1.1]

### Fixed

- typing issues fixed

## [0.1.0]

### Changed

- `HFPlugin` extending `Plugin`

## [0.0.2]

### Changed

- readme updated

### Fixed

- url addresses fixed

## [0.0.1]

### Added

- project init
